/** 
 *******************************************************************************
 * @file     power_mode.c
 * @brief   the application functions of RMC Power_Mode_Change demo for the TOSHIBA
 *          'TMPM330' Device Series 
 * @version V1.001
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "power_mode.h"

/**
  * @brief  mode shift from normal to sleep.
  * @param  None.
  * @retval success or error code
  */

void PowerMode_N2Sleep(void)
{
    __disable_irq();            /* disable INT */

    CG_SetFs(ENABLE);           /* enable low-speed oscillation */

    /* set warm-up time: wait 1.953ms for fosc to warm up */
    CG_SetWarmUpTime(CG_WARM_UP_SRC_XT1, CG_WARM_UP_TIME_EXP_6);
    CG_StartWarmUp();           /* start warm up */

    while (CG_GetWarmUpState() == BUSY)

        /* check whether warm up ends or not */
        /* set warm-up time: wait 3.2768 mS, counter is X1 */
        CG_SetWarmUpTime(CG_WARM_UP_SRC_X1, CG_WARM_UP_TIME_EXP_15);

    CG_SetSTBYMode(CG_STBY_MODE_SLEEP); /* set low power consumption mode sleep */

    NVIC->ICPR[0] = 0xffffffffU;        /* clear the pending INT requests */
    NVIC->ICPR[1] = 0xffffffffU;        /* clear the pending INT requests */
    __DSB();                    /* Errata 548721 */
    __WFI();
    __enable_irq();

}
