/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TMRB_FREQUENCY demo for the TOSHIBA
 *          'TMPM330' Device Series 
 * @version V1.003
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
#include "main.h"
#include "stdbool.h"

/**
  * @brief  The main function of TB8_Frequency demo
  * @param  None
  * @retval None
  */

int main(void)
{
    uint8_t tmp = 0U;
    uint8_t key_info;
    TMRB_InitTypeDef myTMRB;
    TMRB_FFOutputTypeDef myTMRBFFInit;

    GPIO_SetPullUp(KEY_PORT, GPIO_BIT_4, ENABLE);
    GPIO_SetPullUp(KEY_PORT, GPIO_BIT_5, ENABLE);
    GPIO_SetPullUp(KEY_PORT, GPIO_BIT_6, ENABLE);
    GPIO_SetPullUp(KEY_PORT, GPIO_BIT_7, ENABLE);
    GPIO_SetInputEnableReg(KEY_PORT, GPIO_BIT_4, ENABLE);
    GPIO_SetInputEnableReg(KEY_PORT, GPIO_BIT_5, ENABLE);
    GPIO_SetInputEnableReg(KEY_PORT, GPIO_BIT_6, ENABLE);
    GPIO_SetInputEnableReg(KEY_PORT, GPIO_BIT_7, ENABLE);

    LCD_Configuration();
    LCD_Light(ON);

    GPIO_WriteData(GPIO_PG, tmp);

    /* Set PH6 as TB3IN0 */
    GPIO_SetInput(GPIO_PH, GPIO_BIT_6);
    GPIO_EnableFuncReg(GPIO_PH, GPIO_FUNC_REG_1, GPIO_BIT_6);
    GPIO_SetPullUp(GPIO_PH, GPIO_BIT_6, DISABLE);
    GPIO_SetInputEnableReg(GPIO_PH, GPIO_BIT_6, ENABLE);

    myTMRB.Mode = TMRB_EVENT_CNT;
    myTMRB.TrailingTiming = 0U;          /* Specific value depends on system clock */
    myTMRB.UpCntCtrl = TMRB_FREE_RUN;
    myTMRB.LeadingTiming = 0U;           /* Specific value depends on system clock */

    TMRB_Enable(TSB_TB3);
    TMRB_Init(TSB_TB3, &myTMRB);

    /* enable capture, Capture timing is both edges of TBnOUT */
    /* UC clear/disable, source clock is TBnIN0 pin input */
    TMRB_SetCaptureTiming(TSB_TB3, TMRB_CAPTURE_OUTPUT_EDGE);
    TMRB_ExecuteSWCapture(TSB_TB3);

    /* enable double buffer, individual, IDLE stop */
    TMRB_SetIdleMode(TSB_TB3, DISABLE);
    TMRB_SetSyncMode(TSB_TB3, DISABLE);
    TMRB_SetDoubleBuf(TSB_TB3, ENABLE);

    /* no flip-flop output */
    myTMRBFFInit.FlipflopCtrl = TMRB_FLIPFLOP_INVERT;
    myTMRBFFInit.FlipflopReverseTrg = TMRB_DISABLE_FLIPFLOP;
    TMRB_SetFlipFlop(TSB_TB3, &myTMRBFFInit);

    /* no capture, UC clear/enable, source clock is T4 */
    myTMRB.Mode = TMRB_INTERVAL_TIMER;
    myTMRB.ClkDiv = TMRB_CLK_DIV_8;
    myTMRB.TrailingTiming = TMRB8TIME;   /* TMRB8 for frequency measure: 10ms */
    myTMRB.UpCntCtrl = TMRB_AUTO_CLEAR;
    myTMRB.LeadingTiming = 0U;

    TMRB_Enable(TSB_TB8);
    TMRB_Init(TSB_TB8, &myTMRB);

    /* set TBnRG1 as flip-flop output trigger */
    myTMRBFFInit.FlipflopReverseTrg = TMRB_FLIPFLOP_MATCH_TRAILINGTIMING;
    myTMRBFFInit.FlipflopCtrl = TMRB_FLIPFLOP_INVERT;
    TMRB_SetFlipFlop(TSB_TB8, &myTMRBFFInit);

    Send_To_LCD(FIRST_LINE, LCD_COMMAND);
    Send_LCD_Text("K3: Freq Measure");

    while (1) {

        key_info = GPIO_ReadData(KEY_PORT);

        switch (key_info) {     /* read keyboard input */
        case K3:               /* Frequency Measurement */
            do {                /* wait for key released */
                key_info = GPIO_ReadData(KEY_PORT) & KEYRELEASE;
            } while (key_info != KEYRELEASE);
            NVIC_EnableIRQ(INTTB8_IRQn);
            TMRB_SetRunState(TSB_TB3, TMRB_RUN);        /* start TMRB3 */
            TMRB_SetRunState(TSB_TB8, TMRB_RUN);        /* start TMRB8 */

            break;
        default:
            if (fFreqMOK == true) {     /* frequency measure mode and finish measuring */
                fFreqMOK = false;
                Cal_Freq();     /* Calculate average value of frequency */

                Send_To_LCD(FIRST_LINE, LCD_COMMAND);
                Send_LCD_Text("Freq measure");
                Send_To_LCD(SECOND_LINE, LCD_COMMAND);
                Send_LCD_Text(FrequencyToString(gFreq[0]));
            } else {
                /* do nothing */
            }
            break;
        }

    }
}

/**
  * @brief  Calculate average value of frequency
  * @param  None
  * @retval None
  */
void Cal_Freq(void)
{
    uint8_t i;

    for (i = 1U; i < TIMES; i++) {
        gFreq[0] += gFreq[i];
    }
    gFreq[0] = gFreq[0] / TIMES;
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */


#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
