/**
 *******************************************************************************
 * @file    tmpm330_tmrb_int.c
 * @brief   all interrupt request functions definition of TMRB_FREQUENCY demo
 *          for the TOSHIBA 'TMPM330' Device Series 
 * @version V1.002
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "tmpm330_tmrb_int.h"
#include "stdbool.h"

int32_t gFreq[TIMES] = { 0 };

uint8_t fFreqMOK = false;

/**
  * @brief  TMRB8 interrupt service routine  (frequency measure)
  * @param  None
  * @retval None
  */

void INTTB8_IRQHandler(void)
{
    static uint8_t tb8count = 0U;
    TMRB_INTFactor TMRB_Status;
    uint16_t eTMRB_CP0;
    uint16_t eTMRB_CP1;

    TMRB_Status = TMRB_GetINTFactor(TSB_TB3);
    if (!TMRB_Status.Bit.OverFlow) {    /* No timer overflow */
        /* 
           frequency = number of pulses / interval
           number of pulses = |CP0_TMRB3 - CP1_TMRB3|
           interval = 10ms
         */
        eTMRB_CP0 = TMRB_GetCaptureValue(TSB_TB3, TMRB_CAPTURE_0);
        eTMRB_CP1 = TMRB_GetCaptureValue(TSB_TB3, TMRB_CAPTURE_1);
        if (eTMRB_CP0 >= eTMRB_CP1) {
            gFreq[tb8count] = eTMRB_CP0 - eTMRB_CP1;
        } else {
            gFreq[tb8count] = eTMRB_CP1 - eTMRB_CP0;
        }
        gFreq[tb8count] *= 1000U;
        gFreq[tb8count] /= 10U;

        tb8count++;
        if (tb8count >= TIMES) {
            fFreqMOK = true;
            tb8count = 0U;
            NVIC_DisableIRQ(INTTB8_IRQn);
        } else {
            /* do nothing */
        }
    } else {
        /* do nothing */
    }
}

/*********************************** END OF FILE ******************************/
