/** 
 *******************************************************************************
 * @file    tmrb_tostring.c
 * @brief   the application functions of TMRB_FREQUENCY demo for the TOSHIBA
 *          'TMPM330' Device Series 
 * @version V1.001
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmrb_tostring.h"

/**
  * @brief  Frequency to String
  * @param  Fequency value
  * @retval Frequency string to be displayed
  */

char *FrequencyToString(int32_t freq)
{
    static char ret[11] = "f=      0Hz";
    int32_t oldfreq = 0U;
    uint8_t i = 0U;

    if (freq != 0U) {           /* frequency measured is not zero */
        while (freq && (i < 7U)) {
            oldfreq = freq;
            freq = (freq / 10U) * 10U;  /* remove units digit */
            ret[8 - (i++)] = oldfreq - freq + 0x30U;    /* get units digit */
            freq = freq / 10U;
        }
    } else {                    /* frequency measured is zero */
        ret[8] = '0';           /* units digit is zero */
        i = 1U;
    }
    /* blank left digits */
    for (; i < 7U; i++) {
        ret[8 - i] = 0x20U;     /* fill blank */
    }
    return ret;
}
