/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TMRB_PPG demo for the TOSHIBA
 *          'TMPM330' Device Series 
 * @version V1.002
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/**
  * @brief  The main function of TMRB_PPG demo
  * @param  None
  * @retval None
  */

int main(void)
{
    uint8_t tmp = 0U;
    uint8_t Rate = 0U;
    uint16_t LeadingTiming[5] = { 0x08D0, 0x0758, 0x04E6, 0x0273, 0x00FA };      /* leadingtiming: 10%, 25%, 50%, 75%, 90% */
    uint8_t key_info;
    TMRB_InitTypeDef myTMRB;
    TMRB_FFOutputTypeDef PPGFFInit;

    GPIO_SetPullUp(KEY_PORT, GPIO_BIT_4, ENABLE);
    GPIO_SetPullUp(KEY_PORT, GPIO_BIT_5, ENABLE);
    GPIO_SetPullUp(KEY_PORT, GPIO_BIT_6, ENABLE);
    GPIO_SetPullUp(KEY_PORT, GPIO_BIT_7, ENABLE);
    GPIO_SetInputEnableReg(KEY_PORT, GPIO_BIT_4, ENABLE);
    GPIO_SetInputEnableReg(KEY_PORT, GPIO_BIT_5, ENABLE);
    GPIO_SetInputEnableReg(KEY_PORT, GPIO_BIT_6, ENABLE);
    GPIO_SetInputEnableReg(KEY_PORT, GPIO_BIT_7, ENABLE);

    LED_Configuration();
    LCD_Configuration();
    LCD_Light(ON);

    GPIO_WriteData(GPIO_PG, tmp);

    /* Set PI0 as TB0OUT for PPG output */
    GPIO_SetOutput(GPIO_PI, GPIO_BIT_0);
    GPIO_EnableFuncReg(GPIO_PI, GPIO_FUNC_REG_1, GPIO_BIT_0);
    GPIO_SetPullUp(GPIO_PI, GPIO_BIT_0, ENABLE);

    myTMRB.Mode = TMRB_INTERVAL_TIMER;
    myTMRB.ClkDiv = TMRB_CLK_DIV_8;
    myTMRB.UpCntCtrl = TMRB_AUTO_CLEAR;
    myTMRB.TrailingTiming = TMRB0TIME;   /* Specific value depends on system clock */
    myTMRB.LeadingTiming = LeadingTiming[0];      /* Specific value depends on system clock */
    PPGFFInit.FlipflopCtrl = TMRB_FLIPFLOP_CLEAR;
    PPGFFInit.FlipflopReverseTrg = TMRB_FLIPFLOP_MATCH_TRAILINGTIMING | TMRB_FLIPFLOP_MATCH_LEADINGTIMING;

    TMRB_Enable(TSB_TB0);
    TMRB_Init(TSB_TB0, &myTMRB);
    TMRB_SetFlipFlop(TSB_TB0, &PPGFFInit);
    TMRB_SetDoubleBuf(TSB_TB0, ENABLE);
    TMRB_SetRunState(TSB_TB0, TMRB_RUN);

    Send_To_LCD(FIRST_LINE, LCD_COMMAND);
    Send_LCD_Text("K1: Change LeadingTiming");
    Send_To_LCD(SECOND_LINE, LCD_COMMAND);
    Send_LCD_Text(" ");

    while (1) {
        key_info = GPIO_ReadData(KEY_PORT);

        switch (key_info) {     /* read keyboard input */
        case K1:               /* PPG mode */
            do {                /* Wait for key released */
                key_info = GPIO_ReadData(KEY_PORT) & KEYRELEASE;
            } while (key_info != KEYRELEASE);
            Rate++;
            if (Rate >= LEADINGTIMINGMAX) {      /* Change leadingtiming rate */
                Rate = LEADINGTIMINGINIT;
            } else {
                /* do nothing */
            }
            TMRB_ChangeLeadingTiming(TSB_TB0, LeadingTiming[Rate]);       /* Change leadingtiming value of TB0 */

            Send_To_LCD(FIRST_LINE, LCD_COMMAND);
            Send_LCD_Text("PPG Output");
            Send_To_LCD(SECOND_LINE, LCD_COMMAND);
            Send_LCD_Text(LeadingTimingRateToString(Rate));
            break;

        default:
            /* do nothing */
            break;
        }

    }
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
