/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TMRB_TIMER demo for the TOSHIBA
 *          'TMPM330' Device Series 
 * @version V1.002
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/**
  * @brief  The main function of TMRB_TIMER demo
  * @param  None
  * @retval None
  */
int main(void)
{
    uint8_t tmp = 0U;
    TMRB_InitTypeDef myTMRB;

    LED_Configuration();
    LCD_Configuration();
    LCD_Light(ON);

    GPIO_WriteData(GPIO_PG, tmp);

    myTMRB.Mode = TMRB_INTERVAL_TIMER;
    myTMRB.ClkDiv = TMRB_CLK_DIV_8;
    myTMRB.TrailingTiming = TMRB_1ms;       /* Specific value depends on system clock */
    myTMRB.UpCntCtrl = TMRB_AUTO_CLEAR;
    myTMRB.LeadingTiming = TMRB_1ms;     /* Specific value depends on system clock */

    TMRB_Enable(TSB_TB5);
    TMRB_Init(TSB_TB5, &myTMRB);
    TMRB_SetRunState(TSB_TB5, TMRB_RUN);
    NVIC_EnableIRQ(INTTB5_IRQn);

    Send_To_LCD(FIRST_LINE, LCD_COMMAND);
    Send_LCD_Text(" General Timer");
    Send_To_LCD(SECOND_LINE, LCD_COMMAND);
    Send_LCD_Text(" ");

    while (1) {
        /* Do nothing */
    }
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
